% coherenceTest
% examples to explore the coherence spectrum between two signals

clear all
close all

% Generate two sinusoidal signals sampled for 1 second each at 1 kHz. 
% Each sinusoid has a frequency of 250 Hz. One of the signals lags the
% other in phase by pi/3 radians. Both signals are embedded in white 
% Gaussian noise of unit variance.
fs = 1000;              % sampling frequency
f = 250;                % frequency of sine wave in Hz
t = 0:1/fs:1-1/fs;      % sequence of time samples
um = sin(2*pi*f*t)+rand(size(t));           % sine wave signal
% f = f*1.1;              % scale the second frequency by 1+epsilon             
un = sin(2*pi*f*t-pi/3)+rand(size(t));      % phase lagged signal
% un = um(end:-1:1);    % compute coherence of signal and its reverse
sound(um+un,fs)         % play combined signals as sound

% plot two sine wave signals superimposed, with different colors
figure(1)
subplot(2,1,1)
plot(t,um,'r')
hold on
plot(t,un,'b')
hold off
xlabel('Time (s)'), ylabel('Signal amplitude'), title('Signals')
% plot power spectra for two sine wave signals, with different colors
subplot(2,1,2)
pwelch(um,[],[],[],fs)
set(get(gca,'Children'),'Color',[1 0 0])
hold on
pwelch(un,[],[],[],fs)
set(gcf,'Color','w')
title('Power spectra')
hold off

% Use mscohere to compute and plot magnitude-squared coherence of the signals
figure(2)
mscohere(um,un,[],[],[],fs)     
% https://www.mathworks.com/help/signal/ref/mscohere.html
%     [Cxy,F] = mscohere(X,Y,WINDOW,NOVERLAP,NFFT,Fs) returns the magnitude
%     squared coherence estimate computed as a function of physical frequency
%     in Hz. Fs is the sampling frequency specified in Hz.
xlabel('f (Hz)'), title('Magnitude-squared Coherence Spectrum')
ylim([0 1.1])
ax = gca;                   % set tickmarks on axes
ax.XTick = 0:250:500;
ax.YTick = 0:0.25:1;
ax.YLabel.String = [];      % remove tickmarks
% use set and get to modify the line properties
set(get(gca,'Children'),'Color',[1 0 1],'LineWidth',1.5)
set(gcf,'Color','w')

